@@ -2,7 +2,7 @@
 // Syd: rock-solid application kernel
 // benches/sys/gettid.rs: gettid microbenchmarks
 //
-// Copyright (c) 2024 Ali Polatel <alip@chesswob.org>
+// Copyright (c) 2024, 2025 Ali Polatel <alip@chesswob.org>
 // Based in part upon gVisor's gettid_benchmark.cc which is:
 //   Copyright 2020 The gVisor Authors.
 //   SPDX-License-Identifier: Apache-2.0
@@ -14,15 +14,13 @@
 // invoke the kernel via a simple `syscall!` macro.
 
 use brunch::{benches, Bench};
-use libc::SYS_gettid;
-use nix::errno::Errno;
-use syd::syscall;
+use libc::{syscall, SYS_gettid};
 
 /// Benchmark calling the `SYS_gettid` syscall via our macro.
 fn bm_gettid() {
-    // Just call `syscall!` in a tight loop.
-    // gettid(2) never returns error.
-    let _ = syscall!(SYS_gettid);
+    // Just call `syscall` in a tight loop.
+    // SAFETY: gettid(2) never returns error.
+    let _ = unsafe { syscall(SYS_gettid) };
 }
 
 fn main() {
