@@ -245,14 +245,6 @@ fn syscall_open_handler(
             return Err(Errno::ENOENT);
         }
 
-        // Check sandbox lock for Read access.
-        //
-        // a. LockState::Set allows no access.
-        // b. LockState::Read allows open(2) based read-only access.
-        //
-        // `is_lock` is true for LockState::Set and false for LockState::Read.
-        let is_lock = sandbox.locked_read_for(req.pid());
-
         // We use exactly one of Mktemp, Create, Truncate sandboxing
         // categories to improve usability, ie the priority is
         // O_TMPFILE > O_CREAT > O_TRUNC.
@@ -294,9 +286,8 @@ fn syscall_open_handler(
             arg.fsflags.insert(FsFlags::NO_RESOLVE_DOTDOT);
         }
 
-        // Read the remote path.
-        // If lock is on do not check for magic path.
-        let (mut path, magic) = request.read_path(&sandbox, arg, !is_lock)?;
+        // Read the remote path and check for magic path.
+        let (mut path, magic) = request.read_path(&sandbox, arg, true)?;
 
         if sandbox.verbose {
             crate::debug!("ctx": "open", "op": "read_path",
@@ -310,6 +301,16 @@ fn syscall_open_handler(
 
         // Handle the special /dev/syd paths.
         if magic {
+            // Check sandbox lock for Read access.
+            //
+            // a. LockState::Set allows no access.
+            // b. LockState::Read allows open(2) based read-only access.
+            //
+            // `locked_read_for` returns true for LockState::Set, and
+            // false for LockState::Read.
+            if sandbox.locked_read_for(req.pid()) {
+                return Err(Errno::ENOENT);
+            }
             if o_path {
                 return Err(Errno::EINVAL);
             }
