@@ -9,6 +9,9 @@
 //
 // SPDX-License-Identifier: GPL-3.0
 
+// We use Hash{Map,Set} for youki interop.
+#![expect(clippy::disallowed_types)]
+
 use std::{
     collections::{HashMap, HashSet},
     env,
@@ -198,7 +201,6 @@ impl Executor for SydExecutor {
         ignore_signals(opts).or(Err(ExecutorError::CantHandle("Failed to ignore signals!")))?;
 
         // Run command under the Syd sandbox and exit with the return code.
-        #[expect(clippy::disallowed_methods)]
         Supervisor::run(sandbox, None, comm, argv, None, None)
             .map(i32::from)
             .map(exit)
@@ -386,7 +388,6 @@ impl SydTenantContainerBuilder {
 
         let notify_path = Self::setup_notify_listener(&container_dir)?;
         // convert path of root file system of the container to absolute path.
-        #[expect(clippy::disallowed_methods)]
         let rootfs = fs::canonicalize(spec.root().as_ref().ok_or(MissingSpecError::Root)?.path())
             .map_err(LibcontainerError::OtherIO)?;
 
@@ -400,7 +401,6 @@ impl SydTenantContainerBuilder {
         //FIXME: syd's nix != libcontainer's nix
         //let (read_end, write_end) =
         //    pipe2(OFlag::O_CLOEXEC).map_err(LibcontainerError::OtherSyscall)?;
-        #[expect(clippy::disallowed_methods)]
         let (read_end, write_end) = pipe2(OFlag::O_CLOEXEC)
             .map_err(|e| LibcontainerError::OtherIO(std::io::Error::from_raw_os_error(e as i32)))?;
 
@@ -447,7 +447,6 @@ impl SydTenantContainerBuilder {
             let mut buf = [0; 3];
             //FIXME: syd's nix != libcontainer's nix
             //match unistd::read(read_end, &mut buf).map_err(LibcontainerError::OtherSyscall)? {
-            #[expect(clippy::disallowed_methods)]
             match read(&read_end, &mut buf).map_err(|e| {
                 LibcontainerError::OtherIO(std::io::Error::from_raw_os_error(e as i32))
             })? {
@@ -614,11 +613,9 @@ impl SydTenantContainerBuilder {
         //FIXME: syd's procfs != libcontainer's procfs
         // let init_process = procfs::process::Process::new(container_pid.as_raw())?;
         //let ns = self.get_namespaces(init_process.namespaces()?.0)?;
-        #[expect(clippy::disallowed_types)]
         let init_process = procfs::process::Process::new(container_pid.as_raw()).map_err(|_| {
             LibcontainerError::OtherIO(std::io::Error::from_raw_os_error(nix::libc::ESRCH))
         })?;
-        #[expect(clippy::disallowed_methods)]
         let ns = self.get_namespaces(
             init_process
                 .namespaces()
@@ -650,10 +647,8 @@ impl SydTenantContainerBuilder {
             ));
         }
 
-        #[expect(clippy::disallowed_methods)]
         let process = utils::open(process).map_err(LibcontainerError::OtherIO)?;
         let reader = BufReader::new(process);
-        #[expect(clippy::disallowed_methods)]
         let process_spec =
             serde_json::from_reader(reader).map_err(LibcontainerError::OtherSerialization)?;
         Ok(process_spec)
@@ -694,7 +689,6 @@ impl SydTenantContainerBuilder {
     ) -> Result<Option<LinuxCapabilities>, LibcontainerError> {
         if !self.capabilities.is_empty() {
             let mut caps: Vec<syd::caps::Capability> = Vec::with_capacity(self.capabilities.len());
-            #[expect(clippy::disallowed_methods)]
             for cap in &self.capabilities {
                 caps.push(
                     syd::caps::Capability::from_str(cap)
@@ -985,7 +979,6 @@ impl SydInitContainerBuilder {
 
         let notify_path = container_dir.join(NOTIFY_FILE);
         // convert path of root file system of the container to absolute path
-        #[expect(clippy::disallowed_methods)]
         let rootfs = fs::canonicalize(spec.root().as_ref().ok_or(MissingSpecError::Root)?.path())
             .map_err(LibcontainerError::OtherIO)?;
 
@@ -1008,7 +1001,6 @@ impl SydInitContainerBuilder {
         let mut config = YoukiConfig::from_spec(&spec, container.id())?;
         let linux = spec.linux().as_ref().ok_or(MissingSpecError::Linux)?;
         config.cgroup_path = get_cgroup_path(linux.cgroups_path(), &self.container_id);
-        #[expect(clippy::disallowed_methods)]
         config.save(&container_dir).map_err(|err| {
             syd::t!("failed to save config: {err}");
             err
@@ -1052,7 +1044,6 @@ impl SydInitContainerBuilder {
             return Err(LibcontainerError::Exist);
         }
 
-        #[expect(clippy::disallowed_methods)]
         std::fs::create_dir_all(&container_dir).map_err(|err| {
             syd::t!("failed to create container directory: {err}");
             LibcontainerError::OtherIO(err)
@@ -1110,7 +1101,6 @@ impl SydInitContainerBuilder {
             sources.push(PathBuf::from(format!("{syd_dir}/default.syd-3")));
 
             for path in sources {
-                #[expect(clippy::disallowed_methods)]
                 if XPath::new(&path).exists(true) {
                     // Copy the file into the container root.
                     fs::copy(&path, &target_syd_path)
@@ -1129,7 +1119,6 @@ impl SydInitContainerBuilder {
 
         Self::validate_spec(&spec)?;
 
-        #[expect(clippy::disallowed_methods)]
         spec.canonicalize_rootfs(&self.bundle).map_err(|err| {
             syd::t!("failed to canonicalize rootfs: {err}");
             err
@@ -1150,7 +1139,6 @@ impl SydInitContainerBuilder {
 
         if let Some(process) = spec.process() {
             if let Some(_profile) = process.apparmor_profile() {
-                #[expect(clippy::disallowed_methods)]
                 let apparmor_is_enabled = apparmor::is_enabled().map_err(|err| {
                     syd::t!("failed to check if apparmor is enabled");
                     LibcontainerError::OtherIO(err)
@@ -1371,7 +1359,6 @@ impl SydContainerBuilderImpl {
             as_sibling: self.as_sibling,
         };
 
-        #[expect(clippy::disallowed_methods)]
         let (init_pid, need_to_clean_up_intel_rdt_dir) =
             process::container_main_process::container_main_process(&container_args).map_err(
                 |err| {
@@ -1381,7 +1368,6 @@ impl SydContainerBuilderImpl {
             )?;
 
         // if file to write the pid to is specified, write pid of the child
-        #[expect(clippy::disallowed_methods)]
         if let Some(pid_file) = &self.pid_file {
             fs::write(pid_file, format!("{init_pid}")).map_err(|err| {
                 syd::t!("failed to write pid to file: {err}");
@@ -2194,7 +2180,6 @@ fn handle_foreground(init_pid: Pid) -> SydResult<i32> {
             signal => {
                 syd::t!("forwarding signal {}", signal as i32);
                 // There is nothing we can do if we fail to forward the signal.
-                #[expect(clippy::disallowed_methods)]
                 let _ = kill(init_pid, Some(signal)).map_err(|_err| {
                     syd::t!("failed to forward signal to container init process: {_err}")
                 });
@@ -2355,7 +2340,6 @@ fn is_executable(path: &Path) -> std::result::Result<bool, std::io::Error> {
     Ok(metadata.is_file() && permissions.mode() & 0o001 != 0)
 }
 
-#[expect(clippy::disallowed_methods)]
 fn set_name(name: &str) -> std::result::Result<(), Errno> {
     let name = CString::new(name).map_err(|_| Errno::EINVAL)?;
 
