@@ -1016,7 +1016,7 @@ const WORDEXP_SYSCALLS: &[&str] = &[
     "llistxattr",
     "lseek",
     "lstat",
-    "madvise",
+    "madvise", // TODO: confine advices (no-op!).
     "membarrier",
     "mlock",
     "mlock2",
