@@ -43,7 +43,7 @@ use crate::{
     alert,
     compat::{epoll_ctl_mod_safe, epoll_ctl_safe},
     config::*,
-    confine::{confine_scmp_write, scmp_add_setid_rules},
+    confine::{confine_scmp_madvise, confine_scmp_write, scmp_add_setid_rules},
     err::{err2no, scmp2no, SydJoinHandle, SydResult},
     fs::{closeexcept, peer_cred, retry_on_eintr},
     hash::SydHashMap,
@@ -465,6 +465,9 @@ impl IpcWorker {
         // No proc_pid_mem(5) access required here.
         confine_scmp_write(&mut ctx, None, false)?;
 
+        // Allow safe madvise(2) advices.
+        confine_scmp_madvise(&mut ctx)?;
+
         // Allow safe system calls.
         for sysname in IPC_SYSCALLS.iter().chain(VDSO_SYSCALLS) {
             match ScmpSyscall::from_name(sysname) {
